package com.da.dangan.service;

import com.da.common.core.domain.AjaxResult;
import com.da.common.core.domain.TreeSelect;
import com.da.common.core.domain.entity.DaCatalog;

import java.util.List;

/**
 * 档案目录Service接口
 * 
 * @author hs
 * @date 2024-05-08
 */
public interface IDaCatalogService 
{
    /**
     * 查询档案目录
     * 
     * @param id 档案目录主键
     * @return 档案目录
     */
    public DaCatalog selectDaCatalogById(Long id);

    /**
     * 查询所有档案目录列表
     * 
     * @param daCatalog 档案目录
     * @return 档案目录集合
     */
    public List<DaCatalog> selectDaCatalogList(DaCatalog daCatalog);

    /**
     * 查询档案目录列表
     *
     * @param daCatalog 档案目录
     * @return 档案目录集合
     */
    public List<DaCatalog> selectAllDaCatalogList(DaCatalog daCatalog, Long userId);

    /**
     * 新增档案目录
     * 
     * @param daCatalog 档案目录
     * @return 结果
     */
    public int insertDaCatalog(DaCatalog daCatalog);

    /**
     * 修改档案目录
     * 
     * @param daCatalog 档案目录
     * @return 结果
     */
    public int updateDaCatalog(DaCatalog daCatalog);

    /**
     * 批量删除档案目录
     * 
     * @param ids 需要删除的档案目录主键集合
     * @return 结果
     */
    public int deleteDaCatalogByIds(Long[] ids);

    /**
     * 删除档案目录信息
     * 
     * @param id 档案目录主键
     * @return 结果
     */
    public AjaxResult deleteDaCatalogById(Long id);

    boolean checkDaCatalogNameUnique(DaCatalog daCatalog);

    List<DaCatalog> selectCatalogList(Long userId);
    /**
     * 构建前端所需要树结构
     * @param daCatalogs 目录列表
     * @return 树结构列表
     */
    List<DaCatalog> buildCatalogTree(List<DaCatalog> daCatalogs);

    /**
     * 构建前端所需要下拉树结构
     *
     * @param catalogs 目录列表
     * @return 下拉树结构列表
     */
    List<TreeSelect> buildCatalogTreeSelect(List<DaCatalog> catalogs);

    List<Long> selectCatalogIdsByUserId(Long userId);


}
